#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#-------------------------------------------------------------------------------
# This file is part of Mentat system (https://mentat.cesnet.cz/).
#
# Copyright (C) since 2011 CESNET, z.s.p.o (http://www.ces.net/)
# Use of this source is governed by the MIT license, see LICENSE file.
#-------------------------------------------------------------------------------


"""
Base library for Hawat unit tests.
"""

import vial.const
import vial.db
from vial.test import _config_testapp_vial, VialTestCase, ItemCreateVialTestCase, RegistrationVialTestCase

from mentat.datatype.sqldb import SettingsReportingModel, FilterModel, NetworkModel
from mentat.const import CKEY_CORE_DATABASE, CKEY_CORE_DATABASE_EVENTSTORAGE


from hawat import create_app_full
from hawat.app import _config_app
from hawat.const import CFGKEY_MENTAT_CORE


def _config_testapp_hawat(app_config):
    """
    Configure and reconfigure application for testing before instantination.
    """
    _config_testapp_vial(app_config, _config_app)
    app_config['LOG_FILE'] = '/var/tmp/mentat-hawat-utest.log'
    app_config['SQLALCHEMY_DATABASE_URI'] = 'postgresql://mentat:mentat@localhost/mentat_utest'
    app_config[CFGKEY_MENTAT_CORE][CKEY_CORE_DATABASE][CKEY_CORE_DATABASE_EVENTSTORAGE] = {
        'dbname': 'mentat_utest',
        'user': 'mentat',
        'password': 'mentat',
        'host': 'localhost',
        'port': 5432
    }


class BaseAppTestCase(VialTestCase):
    """
    Class for testing :py:class:`hawat.base.HawatApp` application.
    """
    def setup_app(self):
        return create_app_full(
            config_object = 'hawat.config.TestingConfig',
            config_func = _config_testapp_hawat
        )

    def setup_fixtures_db(self):
        super().setup_fixtures_db()
        for fixture in self.fixtures_db:
            if isinstance(fixture, self.app.get_model(vial.const.MODEL_GROUP)):
                SettingsReportingModel(group = fixture)
                vial.db.db_session().add(fixture)
                FilterModel(
                    group = fixture,
                    name = 'FLT_{}'.format(fixture.name),
                    type = 'basic',
                    filter = 'Source.IP4 == 127.0.0.1',
                    enabled = True,
                    description = 'Filter for {}'.format(fixture.name)
                )
                NetworkModel(
                    group = fixture,
                    netname = 'NET_{}'.format(fixture.name),
                    source = 'manual',
                    network = '192.168.0.0/24',
                    description = 'Description for network NET_{}'.format(fixture.name)
                )
        vial.db.db_session().commit()

class ItemCreateTestCase(ItemCreateVialTestCase, BaseAppTestCase):
    """
    Class for testing :py:class:`hawat.base.HawatApp` application.
    """
    def setup_app(self):
        return create_app_full(
            config_object = 'hawat.config.TestingConfig',
            config_func = _config_testapp_hawat
        )

class RegistrationTestCase(RegistrationVialTestCase, BaseAppTestCase):
    """
    Class for testing :py:class:`hawat.base.HawatApp` application.
    """
    def setup_app(self):
        return create_app_full(
            config_object = 'hawat.config.TestingConfig',
            config_func = _config_testapp_hawat
        )
